/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */import {TestBed} from '@angular/core/testing';

import {StorageService} from './storage.service';

describe('StorageService', () => {
  let service: StorageService;

  beforeEach(() => {
    TestBed.configureTestingModule({});
    service = TestBed.inject(StorageService);
  });

  it('should be created', () => {
    expect(service).toBeTruthy();
  });

  it('should save, retrieve, and remove from local storage', () => {
    const key = 'test';
    const payload = 'test payload, yo';
    expect(service.saveLocal(key, payload)).toBeTruthy();
    expect(service.getLocal(key)).toEqual(payload);
    service.deleteLocal(key);
    expect(service.getLocal(key)).toBeNull();
  });

  it('should save, retrieve, and remove from session storage', () => {
    const key = 'test';
    const payload = 'test payload, yo';
    expect(service.saveSession(key, payload)).toBeTruthy();
    expect(service.getSession(key)).toEqual(payload);
    service.deleteSession(key);
    expect(service.getSession(key)).toBeNull();
  });

  it('should save, retrieve, and remove from cookies', () => {
    const key = 'test';
    const payload = 'test payload, yo';
    spyOn(StorageService, 'storageAvailable').and.returnValue(false);
    // cookie fallback for local
    expect(service.saveLocal(key, payload)).toBeTruthy();
    expect(service.getLocal(key)).toEqual(payload);
    service.deleteLocal(key);
    expect(service.getLocal(key)).toBeNull();
    // cookie fallback for session
    expect(service.saveSession(key, payload)).toBeTruthy();
    expect(service.getSession(key)).toEqual(payload);
    service.deleteSession(key);
    expect(service.getSession(key)).toBeNull();
  });

  it('should fail save if storage and cookies are unavailable', () => {
    const key = 'test';
    const payload = 'test payload, yo';
    spyOn(StorageService, 'storageAvailable').and.returnValue(false);
    spyOn(StorageService, 'cookieAvailable').and.returnValue(false);
    // cookie fallback for local
    expect(service.saveLocal(key, payload)).toBeFalsy();
    expect(service.saveSession(key, payload)).toBeFalsy();

  });
});
