#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Tests for workflow.message_architect
"""

from immutable_views import DictView

from workspaces.workflow.message_architect import WorkflowMessageArchitect

r1 = {"request_id": -1}


class TestWorkflowMessageArchitect:
    def test_get_message_template(self):
        execution_msg = WorkflowMessageArchitect(request=r1).get_message_template("workflow_failed")
        assert execution_msg == DictView(
            {
                "service": None,
                "routing_key": None,
                "subject": None,
                "type": "workflow-failed",
            }
        )

        request_msg = WorkflowMessageArchitect(previous_info=r1).get_message_template("ingestion_complete")
        assert request_msg == DictView(
            {
                "service": None,
                "routing_key": None,
                "subject": None,
                "type": "ingestion-complete",
            }
        )

    def test_compose_msg(self):
        execution_msg = WorkflowMessageArchitect(request=r1).compose_message("workflow_failed")
        assert execution_msg == DictView(
            {
                "service": "workflow",
                "routing_key": "workflow",
                "subject": {"request_id": -1},
                "type": "workflow-failed",
            }
        )
